# Fantom Programming Language

Fantom is a portable language that runs on the JVM and modern web browsers. It
features a familiar Java-like syntax, static (and dynamic) typing, elegant
system library, closures, immutability, actor concurrency, and much more.